#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# for use with R version 3.6.1 (2019-07-05) -- "Action of the Toes"
# Copyright (C) 2019 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)
#
# run R script by typing 'Rscript eyed_elater_peerj_r1.R' in terminal 
# OR start R by typing r in terminal and cutting and pasting everything below this line
#
# load pavo (version 2.2.0)
library(pavo)
#
#
#
#   butterflies start below
#   butterflies start below
#
#
# importing spectra from computer into butterflyspecs
butterflyspecs <- getspec("butterflies/", ext = "txt")
#
# convert to rspec object so can be analyzed by pavo
butterflyspecs.new <- as.rspec(butterflyspecs, lim = c(300, 700))
#
# uncomment the line below to take a peak at the data
# head(butterflyspecs.new)
#
# uncomment the line below to see a plot of all the data ('10' because there are 9 files)
# explorespec(butterflyspecs.new[,1:10], by=1, lwd=2, ylim = c(0, 10))
#
# sets up the plotting coming next
par(mfrow = c(1, 1), mar = c(4, 4, 2, 2), oma = c(2, 0, 0, 0))
#
# Plot using mean and standard error, default colors
# '3' because there are 3 'replicates' and '100' y-axis
aggplot(butterflyspecs.new, by = 3,
        ylim = c(0, 100),
        FUN.error = function(x) sd(x) / sqrt(length(x)),
        alpha = 0.3, legend = TRUE)
#
# take the separate means of all the butterfly species spectra 
mbutterflyspecs <- aggspec(butterflyspecs.new, by = 3, FUN = mean)
#
# uncomment the line below to take a peak at the data
# head(mbutterflyspecs)
#
# calculate brightness (total B1, mean B2, intensity B3)
# see http://rafaelmaia.net/pavo/articles/pavo-4-spectraldesc.html#references for refs.
# or see https://github.com/rmaia/pavo/blob/master/vignettes/pavo-4-spectraldesc.Rmd
# in the article B1 is divided by Riemann sum of 100% refl between 300 - 700 nm (40100) to get overall % reflectance
summary(mbutterflyspecs, subset = c('B1', 'B2', 'B3'))
#
#
#
#   beetles start below
#   beetles start below
#
#
# importing spectra from computer into specs
beetlespecs <- getspec("beetle", ext = "txt")
#
# convert to rspec object so can be analyzed by pavo
beetlespecs.new <- as.rspec(beetlespecs, lim = c(300, 700))
#
# uncomment the line below to take a peak at the data
# head(beetlespecs.new)
#
# uncomment the line below to see a plot of all the data ('19' because there are 18 files)
# explorespec(beetlespecs.new[,1:19], by=1, lwd=2, ylim = c(0, 100))
#
# sets up the plotting coming next
par(mfrow = c(1, 1), mar = c(4, 4, 2, 2), oma = c(2, 0, 0, 0))
#
# Plot using mean and standard error, default colors
# '6' because there are 6 'replicates' and '100' y-axis
aggplot(beetlespecs.new, by = 6,
        ylim = c(0, 100),
        FUN.error = function(x) sd(x) / sqrt(length(x)),
        alpha = 0.3, legend = TRUE)
#
# take the means of all the black, white, cuticle spectra 
mbeetlespecs <- aggspec(beetlespecs.new, by = 6, FUN = mean)
#
# uncomment the line below to take a peak at the data
# head(mbeetlespecs)
#
# calculate brightness (total B1, mean B2, intensity B3)
# see http://rafaelmaia.net/pavo/articles/pavo-4-spectraldesc.html#references for refs.
# or see https://github.com/rmaia/pavo/blob/master/vignettes/pavo-4-spectraldesc.Rmd
# in the article B1 is divided by Riemann sum of 100% refl between 300 - 700 nm (40100) to get overall % reflectance
summary(mbeetlespecs, subset = c('B1', 'B2', 'B3'))
#
#
#
#   coated starts below
#   coated starts below
#
#
# importing spectra from computer into coatedspecs
coatedspecs2 <- getspec("coated/", ext = "txt")
#
# convert to rspec object so can be analyzed by pavo
coatedspecs.new <- as.rspec(coatedspecs2, lim = c(300, 700))
#
# uncomment the line below to take a peak at the data
# head(coatedspecs.new)
#
# uncomment the line below to see a plot of all the data ('7' because there are 6 files)
# explorespec(coatedspecs.new[,1:7], by=1, lwd=2, ylim = c(0, 100))
#
# take the means of all the black, white, cuticle spectra 
mcoatedspecs <- aggspec(coatedspecs.new, by = 3, FUN = mean)
#
# uncomment the line below to take a peak at the data
# head(mcoatedspecs)
#
# calculate brightness (total B1, mean B2, intensity B3)
# see http://rafaelmaia.net/pavo/articles/pavo-4-spectraldesc.html#references for refs.
# or see https://github.com/rmaia/pavo/blob/master/vignettes/pavo-4-spectraldesc.Rmd
# in the article B1 is divided by Riemann sum of 100% refl between 300 - 700 nm (40100) to get overall % reflectance
summary(mcoatedspecs, subset = c('B1', 'B2', 'B3'))
#
#
#
#   direction starts below
#   direction starts below
#
#
# importing spectra from computer into directionspecs
directionspecs2 <- getspec("direction/", ext = "txt")
#
# convert to rspec object so can be analyzed by pavo
directionspecs.new <- as.rspec(directionspecs2, lim = c(300, 700))
#
# uncomment the line below to take a peak at the data
# head(directionspecs.new)
#
# plot of all the data
# '10' because there are 9 files
# '2' because spectra are very black
# uncomment the line below to see a plot of all the data
# explorespec(directionspecs.new[,1:10], by=1, lwd=2, ylim = c(0, 2))
#
# take the means of all the direction spectra 
mdirectionspecs <- aggspec(directionspecs.new, by = 3, FUN = mean)
#
# uncomment the line below to take a peak at the data
# head(mdirectionspecs)
#
# calculate brightness (total B1, mean B2, intensity B3)
# see http://rafaelmaia.net/pavo/articles/pavo-4-spectraldesc.html#references for refs.
# or see https://github.com/rmaia/pavo/blob/master/vignettes/pavo-4-spectraldesc.Rmd
# in the article B1 is divided by Riemann sum of 100% refl between 300 - 700 nm (40100) to get overall % reflectance
summary(mdirectionspecs, subset = c('B1', 'B2', 'B3'))
